data = [
  "1 TOCS  ACM Transactions on Computer Systems  ACM  http://dblp.uni -trier.de/db/journals/tocs/",
  "2 TOS  ACM Transactions on Storage  ACM  http://dblp.uni -trier.de/db/journals/tos/",
  "3 TCAD  IEEE Transactions on Computer -Aided Design ofIntegrated Circuits And System  IEEE  http://dblp.uni -trier.de/db/journals/tcad/",
  "4 TC  IEEE Transactions on Computers  IEEE  http://dblp.uni -trier.de/db/journals/tc/index.html",
  "5 TPDS  IEEE Transactions on Parallel and Distributed Systems  IEEE  http://dblp.uni -trier.de/db/journals/tpds/",
  "1 JSAC  IEEE Journal of Selected Areas in Communications  IEEE  http://dblp.uni -trier.de/db/journals/jsac/",
  "2 TMC  IEEE Transactions on Mobile Computing  IEEE  http://dblp.uni -trier.de/db/journals/tmc/",
  "3 TON  IEEE/ACM Transactions on Networking  IEEE/ACM  http://dblp.uni -trier.de/db/journals/ton/",
  "1 TDSC  IEEE Transactions on Dependable and Secure Computing  IEEE  http://dblp.uni -trier.de/db/journals/tdsc/",
  "2 TIFS  IEEE Transactions on Information Forensics and Security  IEEE  http://dblp.uni -trier.d e/db/journals/tifs/",
  "3  Journal of Cryptology  Springer  http://dblp.uni -trier.de/db/journals/joc/  ",
  "1 TOPLAS  ACM Transactions on Programming Languages & Systems  ACM  http://dblp.uni -trier.de/db/journals/toplas/",
  "2 TOSEM  ACM Transactions on Software Engineering  and  Methodology  ACM  http://dblp.uni -trier.de/db/journals/tosem/",
  "3 TSE  IEEE Transactions on Software Engineering  IEEE  http://dblp.uni -trier.de/db/journals/tse/  ",
  "1 TODS  ACM Transactions on Database Systems  ACM  http://dblp.uni -trier.de/db/journals/tods/",
  "2 TOIS  ACM Transactions on Information Systems  ACM  http://dblp.uni -trier.de/db/journals/tois/",
  "3 TKDE  IEEE Transactions on Knowledge and Data Engineering  IEEE  http://dblp.uni -trier.de/db/journals/tkde/",
  "4 VLDBJ  The VLDB Journal  Springer  http://dblp.uni -trier.de/db/journals/vldb/  ",
  "1 TIT  IEEE Transactions on Information Theory  IEEE  http://dblp.uni -trier.de/db/journals/tit/",
  "2 IANDC  Information and Computation  Elsevier  http://dblp.uni -trier.de/db/journals/iandc/",
  "3 SICOMP  SIAM Journal on Computing  SIAM  http://dblp.uni -trier.de/db/journals/siamcomp/  ",
  "1 TOG  ACM Transactions on Graphics  ACM  http://dblp.uni -trier.de/db/journals/tog/",
  "2 TIP  IEEE Transactions on Image Processing  IEEE  http://dblp.uni -trier.de/db/journals/tip/",
  "3 TVCG  IEEE Transactions on Visualization and Computer Graphics  IEEE  http://dblp.uni -trier.de/db/journals/tvcg/  ",
  "1 AI Artificial Intelligence  Elsevier  http://dblp.uni -trier.de/db/journals/ai/",
  "2 TPAMI  IEEE Trans on Pattern Analysis and MachineIntelligence  IEEE  http://dblp.uni -trier.de/db/journals/pami/",
  "3 IJCV  International Journal of Computer Vision  Springer  http://dblp.uni -trier.de/db/journals/ijcv/",
  "4 JMLR  Journal of Machine Learning Research  MIT Press  http://dblp.uni -trier.de/db/journals/jmlr/",
  "1 TOCHI  ACM Transactions on Computer -HumanInteraction  ACM  http://dblp.uni -trier.de/db/journals/tochi/",
  "2 IJHCS  International Journal of Human Computer Studies  Elsevier  http://dblp.uni -trier.de/db/journals/ijmms/  ",
  "1 JACM  Journal of the ACM  ACM  http://dblp.uni -trier.de/db/journals/jacm/",
  "2 Proc. IEEE  Proceedings of the IEEE  IEEE  http://dblp.uni -trier.de/db/journals/pieee/",
  "1 PPoPP  ACM SIGPLAN Symposium on Principles &Practice of Parallel Programming  ACM  http://dblp.uni -trier.de/db/conf/ppopp/",
  "2 FAST  Conference on File and Storage Technologies  USENIX  http://dblp.uni -trier.de/db/conf/fast/",
  "3 DAC  Design Automation Conference  ACM  https://dblp.uni -trier.de/db/conf/dac/",
  "4 HPCA  High  Performance Computer Architecture  IEEE  http://dblp.uni -trier.de/db/conf/hpca/",
  "5 MICRO  IEEE/ACM International Symposium onMicroarchitecture  IEEE/ACM  https://dblp.uni -trier.de/db/conf/micro/",
  "6 SC International Conference for High PerformanceComputing, Networking, Storage, and Analysis  IEEE  http://dblp.uni -trier.de/db/conf/sc/",
  "7 ASPLOS  International Conference on Architectural Supportfor Programming Languages and Operating Systems  ACM  http://dblp.uni -trier.de/db/conf/asplos/",
  "8 ISCA  International Symposium on Computer Architecture  ACM /IEEE  http://dblp.uni -trier.de/db/conf/isca/",
  "9 USENIX ATC  USENIX Annul Technical Conference  USENIX  http://dblp.uni -trier.de/db/conf/usenix/index.html  ",
  "1 SIGCOMM  ACM International Conference on Applications,Technologies, Architectures, and Protocols forComputer Communication  ACM  http://dblp.uni -trier.de/db/conf/sigcomm/index.html",
  "2 Mobi Com  ACM International Conference on MobileComputing and Networking  ACM  http://dblp.uni -trier.de/db/conf/mobicom/",
  "3 INFOCOM  IEEE International Conference on ComputerCommunications  IEEE  http://dblp.uni -trier.de/db/conf/infocom/",
  "4 NSDI  Symposium on Network System Design andImplementation  USENIX  http://dblp.uni -trier.de/db/conf/nsdi/",
  "1 CCS  ACM Conference on Computer andCommunications Security  ACM  http://dblp.uni -trier.de/db/conf/ccs/",
  "2 EUROCRYPT  European Cryptology Conference  Springer  http://dblp.uni -trier.de/db/conf/eurocrypt/",
  "3 S&P  IEEE Symposium on Security and Privacy  IEEE  http://dblp.uni -trier.de/db/conf/sp/",
  "4 CRYPTO  International Cryptology Conference  Springer  http://dblp.uni -trier.de/db/conf/crypto/",
  "5 USENIX Security  Usenix Security Symposium  USENIX Association  http://dblp.uni -trier.de/db/conf/uss/  ",
  "1 PLDI  ACM SIGPLAN Conference on Programming Language Design &Implementation  ACM  http://dblp.uni -trier.de/db/conf/pldi/",
  "2 POPL  ACM SIGPLAN -SIGACT Symposium on Principles of ProgrammingLanguages  ACM  http://dblp.uni -trier.de/db/conf/popl/",
  "3 FSE/ESEC  ACM SIGSOFT Symposium on the Foundation of Software Engineering/European Software Engineering Conference  ACM  http://dblp.uni -trier.de/db/conf/sigsoft/",
  "4 SOSP  ACM Symposium on Operating Systems Principles  ACM  http://dblp.uni -trier.de/db/conf/sosp/",
  "5 OOPSLA  Conference on Object -Oriented Programming Systems, Languages, andApplications  ACM  http://dblp.uni -trier.de/db/conf/oopsla/",
  "6 ASE  International Conference on Automated Software Engineering  IEEE/ACM  http://dblp.uni -trier.de/db/conf/kbse/",
  "7 ICSE  International Conference on Software Engineering  ACM/IEEE  http://dblp.uni -trier.de/db/conf/icse/",
  "8 ISSTA  International Symposium on Software Testing and Analysis  ACM  http://dblp.uni -trier.de/db/conf/issta/",
  "9 OSDI  USENIX Symposium on Operating Systems Design and Implementations  USENIX  http://dblp.uni -trier.de/db/conf/osdi/",
  "1 SIGMOD  ACM Conference on Management of Data  ACM  http://dblp.uni -trier.de/db/conf/sigmod/",
  "2 SIGKDD  ACM Knowledge Discovery and Data Mining  ACM  http://dblp.uni -trier.de/db/conf/kdd/",
  "3 ICDE  IEEE International Conference on DataEngineering  IEEE  http://dblp.uni -trier.de/db/conf/icde/",
  "4 SIGIR  International Conference on Research onDevelopment in Information Retrieval  ACM  http://dblp.uni -trier.de/db/conf/sigir/",
  "5 VLDB  International Conference on Very Large Data Bases  MorganKaufmann/ACM  http://dblp.uni -trier.de/db/conf/vldb/",
  "1 STOC  ACM Symposium on the Theory of Computing  ACM  http://dblp.uni -trier.de/db/conf/stoc/",
  "2 SODA  ACM -SIAM Symposium on Discrete Algorithms  SIAM  http://dblp.uni -trier.de/db/conf/soda/",
  "3 CA V  Computer Aided Verification  Springer  http://dblp.uni -trier.de/db/conf/cav/",
  "4 FOCS  IEEE Annual Symposium on Foundations of Computer Science  IEEE  http://dblp.uni -trier.de/db/conf/focs/",
  "5 LICS  IEEE Symposium on Logic in Computer Science  IEEE  http://dblp.uni -trier.de/db/conf/lics/",
  "1 ACM MM  ACM International Conference on Multimedia  ACM  http://dblp.uni -trier.de/db/conf/mm/",
  "2 SIGGRAPH  ACM SIGGRAPH Annual Conference  ACM  http://dblp.uni -trier.de/db/conf/siggraph/index.html",
  "3 VR  IEEE Virtual Reality  IEEE  http://dblp.uni -trier.de/db/conf/vr/",
  "4 IEEE VIS  IEEE Visualization Conference  IEEE  http://dblp.uni -trier.de/db/conf/visualization/index.html  ",
  "1 AAAI  AAAI Conference on ArtificialIntelligence  AAAI  http://dblp.uni -trier.de/db/conf/aaai/",
  "2 NeurIPS  Annual Conference on NeuralInformation Processing Systems  MIT Press  http://dblp.uni -trier.de/db/conf/nips/",
  "3 ACL  Annual Meeting of theAssociation for ComputationalLinguistics  ACL  http://dblp.uni -trier.de/db/conf/acl/",
  "4 CVPR  IEEE Conference on ComputerVision and Pattern Recognition  IEEE  http://dblp.uni -trier.de/db/conf/cvpr/",
  "5 ICCV  International Conference onComputer Vision  IEEE  http://dblp.uni -trier.de/db/conf/iccv/",
  "6 ICML  International Conference onMachine Learning  ACM  http://dblp.uni -trier.de/db/conf/icml/",
  "7 IJCAI  International Joint Conference on Artificial Intelligence  Morgan Kaufmann  http://dblp.uni -trier.de/db/conf/ijcai/  ",
  "1 CSCW  ACM Conference on Computer SupportedCooperative Work and Social Computing  ACM  http://dblp.uni -trier.de/db/conf/cscw",
  "2 CHI  ACM Conference on Human Factors inComputing Systems  ACM  http://dblp.uni -trier.de/db/conf/chi",
  "3 UbiComp  ACM International Conference on UbiquitousComputing  ACM  http://dblp.uni -trier.de/db/conf/huc/",
  "1 WWW  International World Wide Web Conferences  ACM  http://dblp.uni -trier.de/db/conf/www/",
  "2 RTSS  Real -Time Systems Symposium  IEEE  http://dblp.uni -trier.de/db/conf/rtss/  "
]