data = [
  "1 TACO  ACM Transactions on Architecture and Code Optimization  ACM  http://dblp.uni -trier.de/db/journals/taco/",
  "2 TAAS  ACM Transactions on Autonomous and Adaptive Systems  ACM  http://dblp.uni -trier.de/db/journals/taas/",
  "3 TODAES  ACM Transactions on Design Automation of Electronic Systems  ACM  http://dblp.uni -trier.de/db/journals/todaes/",
  "4 TECS  ACM Transactions on Embedded Computing Systems  ACM  http://dblp.uni -trier.de/db/journals/tecs/",
  "5 TRETS  ACM Transactions on Reconfigurable Technology and Systems  ACM  http://dblp.uni -trier.de/db/journals/trets/",
  "6 TVLSI  IEEE Transactions on Very Large Scale Integration (VLSI) Systems  IEEE  http://dblp.uni -trier.de/db/journals/tvlsi/",
  "7 JPDC  Journal of Parallel and Distributed Computing  Elsevier  http://dblp.uni -trier.de/db/journals/jpdc/",
  "8 JSA  Journal of Systems Architecture: Embedded Software Design  Elsevier  http://dblp.uni -trier.de/db/journals/jsa/",
  "9 PARCO  Parallel Computing  Elsevier  http://dblp.uni -trier.de/db/conf/parco/",
  "10  Performance Evaluation: An International Journal  Elsevier  http://www.journals.elsevier.com/performance -evaluation/  ",
  "1 TOIT  ACM Transactions on Internet Technology  ACM  http://dblp.uni -trier.de/db/journals/toit/",
  "2 TOMCCAP  ACM Transactions on Multimedia Computing,Communications and Applications  ACM  http://dblp.uni -trier.de/db/journals/tomccap/",
  "3 TOSN  ACM Transactions on Sensor Networks  ACM  http://dblp.uni -trier.de/db/journals/tosn/",
  "4 CN  Computer Networks  Elsevier  http://dblp.uni -trier.de/db/journals/cn/",
  "5 TC OM  IEEE Transactions on Communications  IEEE  http://dblp.uni -trier.de/db/journals/tcom/",
  "6 TWC  IEEE Transactions on Wireless Communications  IEEE  http://dblp.uni -trier.de/db/journals/twc/",
  "1 TOPS  ACM Transactions on Privacy and Security  ACM  https://tops.acm.org/",
  "2  Computers & Security  Elsevier  http://dblp.uni -trier.de/db/journals/compsec/",
  "3  Designs, Codes and Cryptography  Springer  http://dblp.uni -trier.de/db/journals/dcc/",
  "4 JCS  Journal of Computer Security  IOS Press  http://dblp.uni -trier.de/db/journals/jcs/",
  "1 ASE  Automated Software Engineering  Springer  http://dblp.uni -trier.de/db/journals/ase/",
  "2 ESE  Empirical Software Engineering  Springer  http://dblp.uni -trier.de/db/journals/ese/",
  "3 TSC  IEEE Transactions on Service Computing  IEEE  http://dblp.uni -trier.de/db/journals/tsc/",
  "4 IETS  IET Software  IET  https://dblp.uni -trier.de/db/journals/iet -sen/",
  "5 IST  Information and Software Technology  Elsevier   http://dblp.uni -trier.de/db/journals/infsof/index.html",
  "6 JFP  Journal of Functional Programming  CambridgeUniversity Press  http://dblp.uni -trier.de/db/journals/jfp/",
  "7  Journal of Software: Evolution and Process  Wiley  http://dblp.uni -trier.de/db/journals/smr/",
  "8 JSS  Journal of Systems and Software  Elsevier   http://dblp.uni -trier.de/db/journals/jss/",
  "9 RE  Requirements Engineering  Springer  http://dblp.uni -trier.de/db/journals/re/",
  "10 SCP  Science of Computer Programming  Elsevier  http://dblp.uni -trier.de/db/journals/scp/",
  "11 SoSyM  Software and System Modeling  Springer  http://dblp.uni -trier.de/db/journals/sosym/",
  "12 STVR  Software Testing, Verification and Reliability  Wiley  http://dblp.uni -trier.de/db/journals/stvr/index.html",
  "13 SPE  Software: Practice and Experience  Wiley  http://dblp.uni -trier.de/db/journals/spe/  ",
  "1 TKDD  ACM Transactions on KnowledgeDiscovery from Data  ACM  http://dblp.uni -trier.de/db/journals/tkdd/",
  "2 TWEB  ACM Transactions on the Web  ACM  http://dblp.uni -trier.de/db/journals/tweb/",
  "3 AEI  Advanced Engineering Informatics  Elsevier  http://dblp.uni -trier.de/db/journals/aei/",
  "4 DKE  Data and Knowledge Engineering  Elsevier  http://dblp.uni -trier.de/db/journals/dke/",
  "5 DMKD  Data Mining and Knowledge Discovery  Springer  http://dblp.uni -trier.de/db/journals/datamine/",
  "6 EJIS  European Journal of InformationSystems  Springer  http://dblp.uni -trier.de/db/journals/ejis/",
  "7  GeoInformatica  Springer  http://dblp.uni -trier.de/db/journals/geoinformatica/",
  "8 IPM  Information Processing and Management  Elsevier  http://dblp.uni -trier.de/db/journals/ipm/",
  "9  Information Sciences  Elsevier  http://dblp.uni -trier.de/db/journals/isci/",
  "10 IS Information Systems  Elsevier  http://dblp.uni -trier.de/db/journals/is/",
  "11 JASIST  Journal of the American Society forInformation Science and Technology  American Society forInformation Science andTechnology  http://dblp.uni -trier.de/db/journals/jasis/",
  "12 JWS  Journal of Web Semantics  Elsevier  http://dblp.uni -trier.de/db/journals/ws/",
  "13 KAIS  Knowledge and Information Systems  Springer  http://dblp.uni -trier.de/db/journals/kais/  ",
  "1 TALG  ACM Transactions on Algorithms  ACM  http://dblp.uni -trier.de/db/journals/talg/",
  "2 TOCL  ACM Transactions on Computational Logic  ACM  http://dblp.uni -trier.de/db/journals/tocl/",
  "3 TOMS  ACM Transactions on Mathematical Software  ACM  http://dblp.uni -trier.de/db/journals/toms/",
  "4 Algorithmica  Algorithmica  Springer  http://dblp.uni -trier.de/db/journals/algorithmica/",
  "5 CC  Computational Complexity  Springer  http://dblp.uni -trier.de/db/journals/cc/",
  "6 FAC  Formal Aspects of Computing  Springer  http://dblp.uni -trier.de/db/journals/fac/",
  "7 FMSD  Formal Methods in System Design  Springer  http://dblp.uni -trier.de/db/journals/fmsd/",
  "8 INFORMS  INFORMS Journal on Computing  INFORMS  http://dblp.uni -trier.de/db/journals/informs/",
  "9 JCSS  Journal of Computer and System Sciences  Elsevier  http://dblp.uni -trier.de/db/journals/jcss/",
  "10 JGO  Journal of Global Optimization  Springer  http://dblp.uni -trier.de/db/journals/jgo/",
  "11 JSC  Journal of Symbolic Computation  Elsevier  http://dblp.uni -trier.de/db/journals/jsc/",
  "12 MSCS  Mathematical Structures in Computer Science  CambridgeUniversity Press  http://dblp.uni -trier.de/db/journals/mscs/",
  "13 TCS  Theoretical Computer Science  Elsevier  http://dblp.uni -trier.de/db/journals/tcs/",
  "1 TOMCCAP  ACM Transactions on Multimedia Computing,Communications and Application  ACM  http://dblp.uni -trier.de/db/journals/tomccap/",
  "2 CAGD  Computer Aided Geometric Design  Elsevier  http://dblp.uni -trier.de/db/journals/cagd/",
  "3 CGF  Computer Graphics Forum  Wiley  http://dblp.uni -trier.de/db/journals/cgf/",
  "4 CAD  Computer -Aided Design  Elsevier  http://dblp.uni -trier.de/db/journals/cad/",
  "5 GM  Graphical Models  Elsevier  http://dblp.uni -trier.de/db/journals/cvgip/",
  "6 TCSVT  IEEE Transactions on Circuits and Systems forVideo Technology  IEEE  http://dblp.uni -trier.de/db/journals/tcsv/",
  "7 TMM  IEEE Transactions on Multimedia  IEEE  http://dblp.uni -trier.de/db/journals/tmm/",
  "8 JASA  Journal of The Acoustical Society of America  AIP  http://scitation.aip.org/content/asa/journal/jasa",
  "9 SIIMS  SIAM Journal on Imaging Sciences  SIAM  http://dblp.uni -trier.de/db/journals/siamis/",
  "10 Speech Com  Speech Communication  Elsevier  http://dblp.uni -trier.de/db/journals/speech/  ",
  "1 TAP  ACM Transactions on Applied Perception  ACM  http://dblp.uni -trier.de/db/journals/tap/",
  "2 TSLP  ACM Transactions on Speech and LanguageProcessing  ACM  http://dblp.uni -trier.de/db/journals/tslp/",
  "3 AAMAS  Autonomous Agents and Multi -Agent Systems  Springer  http://dblp.uni -trier.de/db/journals/aamas/",
  "4   Computational Linguistics  MIT Press  http://dblp.uni -trier.de/db/journals/coling/",
  "5 CVIU  Computer Vision and Image Understanding  Elsevier  http://dblp.uni -trier.de/db/journals/cviu/",
  "6 DKE  Data and Knowledge Engineering  Elsevier  http://dblp.uni -trier.de/db/journals/dke/index.html",
  "7   Evolutionary Computation  MIT Press  http://dblp.uni -trier.de/db/journals/ec/",
  "8 TAC  IEEE Transactions on Affective Computing  IEEE  http://dblp.uni -trier.de/db/journals/taffco/",
  "9 TASLP  IEEE Transactions on Audio, Speech, andLanguage Processing  IEEE  http://dblp.uni -trier.de/db/journals/taslp/",
  "10   IEEE Transactions on Cybernetics  IEEE  http://dblp.uni -trier.de/db/journals/tcyb/",
  "11 TEC  IEEE Transactions on EvolutionaryComputation  IEEE  http://dblp.uni -trier.de/db/journals/tec/",
  "12 TFS  IEEE Transactions on Fuzzy Systems  IEEE  http://dblp.uni -trier.de/db/journals/tfs/",
  "13 TNNLS  IEEE Transactions on Neural Networks andlearning systems  IEEE  http://dblp.uni -trier.de/db/journals/tnn/",
  "14 IJAR  International Journal of ApproximateReasoning  Elsevier  http://dblp.uni -trier.de/db/journals/ijar/  ",
  "15 JAIR  Journal of Artificial Intelligence Research  AAAI  http://dblp.uni -trier.de/db/journals/jair/index.html",
  "16   Journal of Automated Reasoning  Springer  http://dblp.uni -trier.de/db/journals/jar/",
  "17 JSLHR  Journal of Speech, Language, and HearingResearch  American Speech -Language HearingAssociation  http://jslhr.pubs.asha.org/",
  "18   Machine Learning  Springer  http://dblp.uni -trier.de/db/journals/ml/",
  "19   Neural Computation  MIT Press  http://dblp.uni -trier.de/db/journals/neco/",
  "20   Neural Networks  Elsevier  http://dblp.uni -trier.de/db/journals/nn/",
  "21  PR Pattern Recognition  Elsevier  http://dblp.uni -trier.de/db/conf/par/  ",
  "1 CSCW  Computer Supported Cooperative Work  Springer  http://dblp.uni -trier.de/db/journals/cscw/",
  "2 HCI  Human Computer Interaction  Taylor & Francis  http://dblp.uni -trier.de/db/journals/hhci/",
  "3  IEEE Transactions on Human -Machine Systems  IEEE  http://dblp.uni -trier.de/db/journals/thms/",
  "4 IWC  Interacting with Computers  Oxford University Press  http://dblp.uni -trier.de/db/journals/iwc/",
  "5 IJHCI  International Journal of Human -ComputerInteraction  Taylor & Francis  http://dblp.uni -trier.de/db/journals/ijhci/",
  "6 UMUAI  User Modeling and User -Adapted Interaction  Springer  http://dblp.uni -trier.de/db/journals/umuai/",
  "1  Bioinformatics  Oxford University Press  http://dblp.uni -trier.de/db/journals/bioinformatics/",
  "2  Briefings in Bioinformatics  Oxford University Press  http://dblp.uni -trier.de/db/journals/bib/",
  "3 Cognition  Cognition \uff1aInternational Journal of CognitiveScience  Elsevier  http://www.journals.elsevier.com/cognition/",
  "4 TASAE  IEEE Transactions on Automation Scienceand Engineering  IEEE  http://dblp.uni -trier.de/db/journals/tase/",
  "5 TGARS  IEEE Transactions on Geoscience andRemote Sensing  IEEE  http://dblp.uni -trier.de/db/journals/tgrs/",
  "6 TITS  IEEE Transactions on IntelligentTransportation Systems  IEEE  http://dblp.uni -trier.de/db/journals/tits/",
  "7 TMI  IEEE Transactions on Medical Imaging  IEEE  http://dblp.uni -trier.de/db/journals/tmi/",
  "8 TR  IEEE Transactions on Robotics  IEEE  http://dblp.uni -trier.de/db/journals/trob/",
  "9 TCBB  IEEE -ACM Transactions on ComputationalBiology and Bioinformatics  IEEE/ACM  http://dblp.uni -trier.de/db/journals/tcbb/",
  "10 JCST  Journal of Computer Science and Technology  SCIENCE PRESS/Springer  http://dblp.uni -trier.de/db/journals/jcst/",
  "11 JAMIA  Journal of the American Medical InformaticsAssociation  BMJ Journals  http://dblp.uni -trier.de/db/journals/jamia/",
  "12  PLOS Computational Biology  Public Library of Science  http://dblp.uni -trier.de/db/journals/ploscb/",
  "13  Science China Information Sciences  Science in ChinaPress/Springer  http://dblp.uni -trier.de/db/journals/chinaf/",
  "14  The Computer Journal  Oxford University Press  http://dblp.uni -trier.de/db/journals/cj/  ",
  "15  World Wide Web Journal  Springer  http://dblp.uni -trier.de/db/journals/wwwj/  ",
  "1 SoCC  ACM Symposium on Cloud Computing  ACM  http://dblp.uni -trier.de/db/conf/cloud/",
  "2 SPAA  ACM Symposium on Parallelism in Algorithms and Architectures  ACM  http://dblp.uni -trier.de/db/conf/spaa/",
  "3 PODC  ACM Symposium on Principles of Distributed Computing  ACM  http://dblp.uni -trier.de/db/conf/podc/",
  "4 FPGA  ACM/SIGDA International Symposium on Field -ProgrammableGate Arrays  ACM  http://dblp.uni -trier.de/db/conf/fpga/",
  "5 CGO  Code Generation and Optimization  IEEE/ACM  http://dblp.uni -trier.de/db/conf/cgo/",
  "6 DATE  Design, Automation & Test in Europe  IEEE/ACM  http://dblp.uni -trier.de/db/conf/date/",
  "7 EuroSys  European Conference on Computer Systems  ACM  http://dblp.uni -trier.de/db/conf/eurosys/",
  "8 HOT CHIPS  Hot Chips: A Symposium on High Performance Chips  IEEE  http://www.hotchips.org/",
  "9 CLUSTER  IEEE International Conference on Cluster Computing  IEEE  https://dblp.uni -trier.de/db/conf/cluster/",
  "10 ICCD  International Conference on Computer Design  IEEE  http://dblp.uni -trier.de/db/conf/iccd/",
  "11 ICCAD  International Conference on Computer -Aided Design  IEEE/ACM  http://dblp.uni -trier.de/db/conf/iccad/",
  "12 ICDCS  International Conference on Distributed Computing Systems  IEEE  http://dblp.uni -trier.de/db/conf/icdcs/",
  "13 CODES+ISSS  International Conference on Hardware/Software Co -design andSystem Synthesis  ACM/ IEEE  http://dblp.uni -trier.de/db/conf/codes/index.html",
  "14 HiPEAC  International Conference on High Performance and EmbeddedArchitectures and Compilers  ACM  http://dblp.uni -trier.de/db/conf/hipeac/  ",
  "15 SIGMETRICS  International Conference on Measurement and Modeling ofComputer Systems  ACM  http://dblp.uni -trier.de/db/conf/sigmetrics/",
  "16 PACT  International Conference on Parallel Architectures andCompilation Techniques  IEEE/ACM  http://dblp.uni -trier.de/db/conf/IEEEpact/",
  "17 ICPP  International Conference on Parallel Processing   http://dblp.uni -trier.de/db/conf/icpp/",
  "18 ICS  International Conference on Supercomputing  ACM  http://dblp.uni -trier.de/db/conf/ics/",
  "19 VEE  International Conference on Virtual Execution Environments  ACM  http://dblp.uni -trier.de/db/conf/vee/",
  "20 IPDPS  International Parallel & Distributed Processing Symposium  IEEE  http://dblp.uni -trier.de/db/conf/ipps/",
  "21 Performance  International Symposium on Computer Performance Modeling,Measurements and Evaluation  ACM  http://dblp.uni -trier.de/db/conf/performance/",
  "22 HPDC  International Symposium on High Performance DistributedComputing  IEEE  http://dblp.uni -trier.de/db/conf/hpdc/",
  "23 ITC  International Test Conference  IEEE  http://dblp.uni -trier.de/db/conf/itc/",
  "24 LISA  Large Installation System Administration Conference  USENIX  http://dblp.uni -trier.de/db/conf/lisa/",
  "25 MSST  Mass Storage Systems and Technologies  IEEE  http://dblp.uni -trier.de/db/conf/mss/",
  "26 RTAS  Real -Time and Embedded Technology and ApplicationsSymposium  IEEE  http://dblp.uni -trier.de/db/conf/rtas/",
  "1 SenSys  ACM Conference on Embedded Networked Sensor Systems  ACM  http://dblp.uni -trier.de/db/conf/sensys/",
  "2 CoNEXT  ACM International Conference on Emerging NetworkingExperiments and Technologies  ACM  http://dblp.uni -trier.de/db/conf/conext/",
  "3 SECON  IEEE Communications Society Conference on Sensor and Ad HocCommunications and Networks  IEEE  http://dblp.uni -trier.de/db/conf/secon/",
  "4 IPSN  International Conference on Information Processi ng in SensorNetworks  IEEE/ACM  http://dblp.uni -trier.de/db/conf/ipsn/",
  "5 MobiSys  International Conference on Mobile Systems, Applications, andServices  ACM  http://dblp.uni -trier.de/db/conf/mobisys/",
  "6 ICNP  International Conference on Network Protocols  IEEE  http://dblp.uni -trier.de/db/conf/icnp/",
  "7 MobiHoc  International Symposium on Mobile Ad Hoc Networking andComputing  ACM/IEEE  http://dblp.uni -trier.de/db/conf/mobihoc/",
  "8 NOSSDAV  International Workshop on Network and Operating System Supportfor Digital Audio and Video  ACM  http://dblp.uni -trier.de/db/conf/nossdav/",
  "9 IWQoS  International Workshop on Quality of Service  IEEE  http://dblp.uni -trier.de/db/conf/iwqos/",
  "10 IMC  Internet Measurement Conference  ACM/USENIX  http://dblp.uni -trier.de/db/conf/imc/  ",
  "1 ACSAC  Annual Computer Security Applications Conference  IEEE  http://dblp.uni -trier.de/db/conf/acsac/",
  "2 ASIACRYPT  Annual International Conference on the Theory andApplication of Cryptology and Information Security  Springer  http://dblp.uni -trier.de/db/conf/asiacrypt/",
  "3 ESORICS  European Symposium on Research in Computer Security  Springer  http://dblp.uni -trier.de/db/conf/esorics/",
  "4 FSE  Fast Software Encryption  Springer  http://dblp.uni -trier.de/db/conf/fse/",
  "5 CSFW  IEEE Computer Security Foundations Workshop  IEEE  http://dblp.uni -trier.de/db/conf/csfw/",
  "6 SRDS  IEEE International Symposium on Reliable DistributedSystems  IEEE  http://dblp.uni -trier.de/db/conf/srds/",
  "7 CHES  International Conference on Cryptographic Hardware andEmbedded Systems  Springer  http://dblp.uni -trier.de/db/conf/ches/",
  "8 DSN  International Conference on Dependable Systems andNetworks  IEEE/IFIP  http://dblp.uni -trier.de/db/conf/dsn/",
  "9 RAID  International Symposium on Recent Advances in IntrusionDetection  Springer  http://dblp.uni -trier.de/db/conf/raid/",
  "10 PKC  International Workshop on Practice and Theory in PublicKey Cryptography  Springer  http://dblp.uni -trier.de/db/conf/pkc/",
  "11 NDSS  ISOC Network and Distributed System SecuritySymposium  ISOC  http://dblp.uni -trier.de/db/conf/ndss/",
  "12 TCC  Theory of Cryptography Conference  Springer  http://dblp.uni -trier.de/db/conf/tcc/",
  "1 ECOOP  European Conference on Object -Oriented Programming  AITO  http://dblp.uni -trier.de/db/conf/ecoop/",
  "2 ETAPS  European Joint Conferences on Theory and Practice ofSoftware  Springer  http://dblp.uni -trier.de/db/conf/etaps/",
  "3 ICPC  IEEE International Conference on ProgramComprehension  IEEE  http://dblp.uni -trier.de/db/conf/iwpc/",
  "4 RE  IEEE International Requirement Engineering Conference  IEEE  http://db lp.uni -trier.de/db/conf/re/",
  "5 CAiSE  International Conference on Advanced InformationSystems Engineering  Springer  http://dblp.uni -trier.de/db/conf/caise/",
  "6 ICFP  International Conference on Function Programming  ACM  http://dblp.uni -trier.de/db/conf/icfp/",
  "7 LCTES  International Conference on Languages, Compilers andTools for Embedded Systems  ACM  http://dblp.uni -trier.de/db/conf/lctrts/",
  "8 MoDELS  International Conference on Model Driven EngineeringLanguages and Systems  ACM, IEEE  http://dblp.uni -trier.de/db/conf/models/",
  "9 CP International Conference on Principles and Practice ofConstraint Programming  Springer  http://dblp.uni -trier.de/db/conf/cp/",
  "10 ICSOC  International Conference on Service Oriented Computing  Springer  http://dblp.uni -trier.de/db/conf/icsoc/  ",
  "11 SANER  International Conference on Software Analysis, Evolution,and Reengineering  IEEE  http://dblp.uni -trier.de/db/conf/wcre/",
  "12 ICSME  International Conference on Software Maintenance andEvolution  IEEE  http://dblp.uni -trier.de/db/conf/icsm/",
  "13 VMCAI  International Conference on Verification, Model Checking,and Abstract Interpretation  Springer  http://dblp.uni -trier.de/db/conf/vmcai/",
  "14 ICWS  International Conference on Web Services \uff08ResearchTrack\uff09 IEEE  http://dblp.uni -trier.de/db/conf/icws/",
  "15 Middleware  International Middleware Conference  ACM/IFIP/USENIX  http://dblp.uni -trier.de/db/conf/middleware/",
  "16 SAS  International Static Analysis Symposium  Springer  http://dblp.uni -trier.de/db/conf/sas/",
  "17 ESEM  International Symposium on Empirical SoftwareEngineering and Measurement  ACM/IEEE  http://dblp.uni -trier.de/db/conf/esem/",
  "18 FM  International Symposium on Formal Methods  FME  http://dblp.uni -trier.de/db/conf/fm/",
  "19 ISSRE  International Symposium on Software ReliabilityEngineering  IEEE  http://dblp.uni -trier.de/db/conf/issre/",
  "20 HotOS  USENIX Workshop on Hot Topics in Operating Systems  USENIX  http://dblp.uni -trier.de/db/conf/hotos/  ",
  "1 CIKM  ACM International Conference on Informationand Knowledge Management  ACM  http://dblp.uni -trier.de/db/conf/cikm/",
  "2 WSDM  ACM International Conference on Web Searchand Data Mining  ACM  http://dblp.uni -trier.de/db/conf/wsdm/",
  "3 PODS  ACM Symposium on Principles of DatabaseSystems  ACM  http://dblp.uni -trier.de/db/conf/pods/",
  "4 DASFAA  Database Systems for Advanced Applications  Springer  http://dblp.uni -trier.de/db/conf/dasfaa/",
  "5 ECML -PKDD  European Conference on Machine Learningand Principles and Practice of KnowledgeDiscovery in Databases  Springer  http://dblp.uni -trier.de/db/conf/pkdd/",
  "5 ECML -PKDD  European Conference on Machine Learningand Principles and Practice of KnowledgeDiscovery in Databases  Springer  http://dblp.uni -trier.de/db/conf/ecml/",
  "6 ISWC  IEEE International Semantic Web Conference  IEE E http://dblp.uni -trier.de/db/conf/semweb/",
  "7 ICDM  International Conference on Data Mining  IEEE  http://dblp.uni -trier.de/db/conf/icdm/",
  "8 ICDT  International Conference on Database Theory  Springer  http://dblp.uni -trier.de/db/conf/icdt/",
  "9 EDBT  International Conference on Extending DBTechnology  Springer  http://dblp.uni -trier.de/db/conf/edbt/",
  "10 CIDR  International Conference on Innovative DataSystems Research  Online Proceeding  http://dblp.uni -trier.de/db/conf/cidr/",
  "11 SDM  SIAM International Conference on DataMining  SIAM  http://dblp.uni -trier.de/db/conf/sdm/",
  "1 SoCG  ACM Symposium on Computational Geometry  ACM  http://dblp.uni -trier.de/db/conf/compgeom/",
  "2 ESA  European Symposium on Algorithms  Springer  http://dblp.uni -trier.de/db/conf/esa/",
  "3 CCC  IEEE Conference on Computational Complexity  IEEE  http://dblp.uni -trier.de/db/conf/coco/",
  "4 ICALP  International Colloquium on Automata, Languages andProgramming  Springer  http://dblp.uni -trier.de/db/conf/icalp/",
  "5 CADE/IJCAR  International Conference on AutomatedDeduction/International Joint Conference onAutomated Reasoning  Springer  http://dblp.uni -trier.de/db/conf/cade/",
  "6 CONCUR  International Conference on Concurrency Theory  Springer  http://dblp.uni -trier.de/db/conf/concur/",
  "7 HSCC  International Conference on Hybrid Systems:Computation and Control  Springer and ACM  http://dblp.uni -trier.de/db/conf/hybrid/",
  "8 SAT  Theory and Applications of Satisfiability Testing  Springer  http://dblp.uni -trier.de/db/conf/sat/",
  "1 ICMR  ACM SIGMM International Conference onMultimedia Retrieval  ACM  http://dblp.uni -trier.de/db/conf/mir/",
  "2 SI3D  ACM Symposium on Interactive 3D Graphics  ACM  http://dblp.uni -trier.de/db/conf/si3d/",
  "3 SCA  ACM/Eurographics Symposium on ComputerAnimation  ACM  http://dblp.uni -trier.de/db/conf/sca/index.html",
  "4 DCC  Data Compression Conference  IEEE  http://dblp.uni -trier.de/db/conf/dcc/",
  "5 EG  Eurographics  Wiley/ Blackwell  http://dblp.uni -trier.de/db/conf/eurographics/",
  "6 EuroVis  Eurographics  Conference on Visualization  ACM  http://dblp.uni -trier.de/db/conf/vissym/",
  "7 SGP  Eurographics Symposium on GeometryProcessing   Wiley/Blackwell  http://dblp.uni -trier.de/db/conf/sgp/",
  "8 EGSR  Eurographics Symposium on Rendering  Wiley/Blackwell  http://dblp.uni -trier.de/db/conf/rt/",
  "9 ICASSP  IEEE International Conference on Acoustics,Speech and SP  IEEE  http://dblp.uni -trier.de/db/conf/icassp/",
  "10 ICME  IEEE International Conference onMultimedia & Expo  IEEE  http://dblp.uni -trier.de/db/conf/icmcs/",
  "11 ISMAR  International Symposium on Mixed andAugmented Reality  IEEE/ACM  http://dblp.uni -trier.de/db/conf/ismar/",
  "12 PG  Pacific Graphics: The Pacific Conference on Computer Graphics and Applications  Wiley/Blackwell  http://dblp.uni -trier.de/db/conf/pg/index.html  ",
  "13 SPM  Symposium on Solid and Physical Modeling  SMA/Elsevier  http://dblp.uni -trier.de/db/conf/sma/  ",
  "1 COLT  Annual Conference onComputational Learning Theory  Springer  http://dblp.uni -trier.de/db/conf/colt/",
  "2 EMNLP  Conference on EmpiricalMethods in Natural LanguageProcessing  ACL  http://dblp.uni -trier.de/db/conf/emnlp/",
  "3 ECAI  European Conference onArtificial Intelligence  IOS Press  http://dblp.uni -trier.de/db/conf/ecai/",
  "4 ECCV  European Conference onComputer Vision  Springer  http://dblp.uni -trier.de/db/conf/eccv/",
  "5 ICRA  IEEE International Conference onRobotics and Automation  IEEE  http://dblp.uni -trier.de/db/conf/icra/",
  "6 ICAPS  International Conference onAutomated Planning andScheduling  AAAI  http://dblp.uni -trier.de/db/conf/aips/",
  "7 ICCBR  International Conference onCase -Based Reasoning andDevelopment  Springer  http://dblp.uni -trier.de/db/conf/iccbr/",
  "8 COLING  International Conference onComputational Linguistics  ACM  http://dblp.uni -trier.de/db/conf/coling/  ",
  "9 KR  International Conference onPrinciples of KnowledgeRepresentation and Reasoning  Morgan Kaufmann  http://dblp.uni -trier.de/db/conf/kr/",
  "10 UAI  International Conference onUncertainty in ArtificialIntelligence  AUAI  http://dblp.uni -trier.de/db/conf/uai/",
  "11 AAMAS  International Joint Conference onAutonomous Agents and Multi -agent Systems  Springer  http://dblp.uni -trier.de/db/conf/atal/index.html",
  "12 PPSN  Parallel Problem Solving from Nature  Springer  http://dblp.uni -trier.de/db/conf/ppsn/  ",
  "1 GROUP  ACM Conference on Supporting Group Work  ACM  http://dblp.uni -trier.de/db/conf/group/",
  "2 IUI  ACM International Conference on Intelligent UserInterfaces  ACM  http://dblp.uni -trier.de/db/conf/iui/",
  "3 ITS  ACM International Conference on InteractiveTabletops and Surfaces  ACM  http://dblp.uni -trier.de/db/conf/tabletop/",
  "4 UIST  ACM Symposium on User Interface Software andTechnology  ACM  http://dblp.uni -trier.de/db/conf/uist/",
  "5 ECSCW  European Conference on Computer SupportedCooperative Work  Springer  http://dblp.uni -trier.de/db/conf/ecscw/",
  "6 PERCOM  IEEE International Conference on PervasiveComputing and Communications  IEEE  http://dblp.uni -trier.de/db/conf/percom/",
  "7 MobileHCI  International Conference on Human Computer Interaction with Mobile Devices and Services  ACM  http://dblp.uni -trier.de/db/conf/mhci/  ",
  "1 CogSci  Cognitive Science Society Annual Conference  Psychology Press  https://dblp.uni -trier.de/db/conf/cogsci/",
  "2 BIBM  IEEE International Conference on Bioinformaticsand Biomedicine  IEEE  http://dblp.uni -trier.de/db/conf/bibm/",
  "3 EMSOFT  International Conference on Embedded Software  ACM/IEEE/IFIP  http://dblp.uni -trier.de/db/conf/emsoft/",
  "4 ISMB  International conference on Intelligent Systems forMolecular Biology  Oxford Journals  http://www.iscb.org/about -ismb",
  "5 RECOMB  International Conference on Research inComputational Molecular Biology  Springer  http://dblp.uni -trier.de/db/conf/recomb/"
]