data = [
  "1 JETC  ACM Journal on Emerging Technologies inComputing Systems  ACM  http://dblp.uni -trier.de/db/journals/jetc/",
  "2  Concurrency and Computation: Practice andExperience  Wiley  http://dblp.uni -trier.de/db/journals/concurrency/",
  "3 DC  Distributed Computing  Springer  http://dblp.uni -trier.de/db/journals/dc/",
  "4 FGCS  Future Generation Computer Systems  Elsevier  http://dblp.uni -trier.de/db/journals/fgcs/",
  "5 TCC  IEEE Transactions on Cloud Computing  IEEE  https://dblp.uni -trier.de/db/journals/tcc/",
  "6 Integration  Integration, the VLSI Journal  Elsevier  http://dblp.uni -trier.de/db/journals/integration/",
  "7 JET TA  Journal of Electronic Testing -Theory andApplications  Springer  http://link.springer.com/journal/10836",
  "8 JGC  Journal of Grid computing  Springer  https://dblp.uni -trier.de/db/journals/grid/",
  "9 MICPRO  Microprocessors and Microsystems: EmbeddedHardware Design  Elsevier  http://dblp.uni -trier.de/db/journals/mam/",
  "10 RTS  Real -Time Systems  Springer  http://dblp.uni -trier.de/db/journals/rts/",
  "11 TJSC  The Journal of Supercomputing  Springer  http://dblp.uni -trier.de/db/journals/tjs/  ",
  "1  Ad Hoc Networks  Elsevier  http://dblp.uni -trier.de/db/journals/adhoc/",
  "2 CC  Computer Communications  Elsevier  http://dblp.uni -trier.de/db/journals/comcom/",
  "3 TNSM  IEEE Transactions on Network and ServiceManagement  IEEE  http://dblp.uni -trier.de/db/journals/tnsm/",
  "4  IET Communications  IET  http://dblp.uni -trier.de/db/journals/iet -com/",
  "5 JNCA  Journal of Network and Computer Applications  Elsevier  http://dblp.uni -trier.de/db/journals/jnca/",
  "6 MONET  Mobile Networks & Applications  Springer  http://dblp.uni -trier.de/db/journals/monet/",
  "7  Networks  Wiley  http://dblp.uni -trier.de/db/journals/networks/",
  "8 PPNA  Peer -to-Peer Networking and Applications  Springer  http://dblp.uni -trier.de/db/journals/ppna/",
  "9 WCMC  Wireless Communications & Mobile Computing  Wiley.  http://dblp.uni -trier.de/db/journals/wicomm/",
  "10  Wireless Networks  Springer  http://dblp.uni -trier.de/db/journals/winet/  ",
  "1 CLSR  Computer Law and Security Review  Elsevier  http://www.journals.elsevier.com/computer -law -and -security -review/",
  "2   EURASIP Journal on Information Security  Springer  http://dblp.uni -trier.de/db/journals/ejisec/",
  "3   IET Information Security  IET  http://dblp.uni -trier.de/db/journals/iet -ifs/",
  "4 IMCS  Information Management & Computer Security  Emerald  http://dblp.uni -trier.de/db/journals/imcs/",
  "5 IJICS  International Journal of Information and Computer Security  Inderscience  http://dblp.uni -trier.de/db/journals/ijics/",
  "6 IJISP  International Journal of Information Security and Privacy  Idea Group Inc  http://dblp.uni -trier.de/db/journals/ijisp/",
  "7 JISA  Journal of Information Security and Application  Elsevier  https://dblp.uni -trier.de/db/journals/istr/",
  "8 SCN  Security and Communication Networks  Wiley  http://dblp.uni -trier.de/db/journals/scn/  ",
  "1 CL  Computer Languages, Systems and Structures  Elsevier  http://dblp.uni -trier.de/db/journals/cl/index.html",
  "2 IJSEKE  International Journal on Software Engineering andKnowledge Engineering  World Scientific  http://dblp.uni -trier.de/db/journals/ijseke/index.html",
  "3 STTT  International Journal on Software Tools for TechnologyTransfer  Springer  http://dblp.uni -trier.de/db/journals/sttt/",
  "4 JLAP  Journal of Logic and Algebraic Programming  Elsevier  http://dblp.uni -trier.de/db/journals/jlp/jlap.html",
  "5 JWE  Journal of Web Engineering  Rinton Press  http://dblp.uni -trier.de/db/journals/jwe/",
  "6 SOCA  Service Oriented Computing and Applications  Springer  http://dblp.uni -trier.de/db/journals/soca/",
  "7 SQJ  Software Quality Journal  Springer   http://dblp.uni -trier.de/db/journals/sqj/",
  "8 TPLP  Theory and Practice of Logic Programming  Cambridge UniversityPress  http://dblp.uni -trier.de/db/journals/tplp/",
  "1 DPD  Distributed and Parallel Databases  Springer  http://dblp.uni -trier.de/db/journals/dpd/",
  "2 I&M  Information and Management  Elsevier  http://dblp.uni -trier.de/db/journals/iam/",
  "3 IPL  Information Processing Letters  Elsevier  http://dblp.uni -trier.de/db/journals/ipl/",
  "4 IR Information Retrieval Journal  Springer  http://dblp.uni -trier.de/db/journals/ir/",
  "5 IJCIS  International Journal of Cooperative Information Systems  World Scientific  http://dblp.uni -trier.de/db/journals/ijcis/",
  "6 IJGIS  International Journal of Geographical InformationScience  Taylor & Francis  http://dblp.uni -trier.de/db/journals/gis/",
  "7 IJIS  International Journal of Intelligent Systems  Wiley  http://dblp.uni -trier.de/db/journals/ijis/",
  "8 IJKM  International Journal of Knowledge Management  IGI  http://dblp.uni -trier.de/db/journals/ijkm/",
  "9 IJSWIS  International Journal on Semantic Web and InformationSystems  IGI  http://dblp.uni -trier.de/db/journals/ijswis/",
  "10 JCIS  Journal of Computer Information Systems  IACIS  http://dblp.uni -trier.de/db/journals/jcis/",
  "11 JDM  Journal of Database Management  IGI -Global  http://dblp.uni -trier.de/db/journals/jdm/",
  "12 JGITM  Journal of Global Information Technology Management  Ivy LeaguePublishing  http://www.tandfonline.com/loi/ugit20#.Vnv35pN97rI",
  "13 JIIS  Journal of Intelligent Information Systems  Springer  http://dblp.uni -trier.de/db/journals/jiis/",
  "14 JSIS  Journal of Strategic Information Systems  Elsevier  http://dblp.uni -trier.de/db/journals/jsis/  ",
  "1 ACTA  Acta Informatica  Springer  http://dblp.uni -trier.de/db/journals/acta/",
  "2 APAL  Annals of Pure and Applied Logic  Elsevier  http://dblp.uni -trier.de/db/journals/apal/",
  "3 DAM  Discrete Applied Mathematics  Elsevier  http://dblp.uni -trier.de/db/journals/dam/",
  "4 FUIN  Fundamenta Informaticae  IOS Press  http://dblp.uni -trier.de/db/journals/fuin/",
  "5 LISP  Higher -Order and Symbolic Computation  Springer  http://dblp.uni -trier.de/db/journals/lisp/",
  "6 IPL  Information Processing Letters  Elsevier  http://dblp.uni -trier.de/db/journals/ipl/",
  "7 JCOMPLEXITY  Journal of Complexity  Elsevier  http://dblp.uni -trier.de/db/journals/jc/",
  "8 LOGCOM  Journal of Logic and Computation  Oxford University Press  http://dblp.uni -trier.de/db/journals/logcom/",
  "9 JSL  Journal of Symbolic Logic  Association for Symbolic Logic  http://dblp.uni -trier.de/db/journals/jsyml/",
  "10 LMCS  Logical Methods in Computer Science  LMCS  http://dblp.uni -trier.de/db/journals/lmcs/",
  "11 SIDMA  SIAM Journal on Discrete Mathematics  SIAM  http://dblp.uni -trier.de/db/journals/siamdm/",
  "12   Theory of Computing Systems  Springer  http://dblp.uni -trier.de/db/journals/mst/",
  "1 CGTA  Computational Geometry: Theory andApplications  Elsevier  http://dblp.uni -trier.de/db/journals/comgeo/",
  "2 CAVW  Computer Animation and Virtual Worlds  Wiley  http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1546-427X",
  "3 C&G  Computers & Graphics  Elsevier  http://dblp.uni -trier.de/db/journals/cg/",
  "4 DCG  Discrete & Computational Geometry  Springer  http://dblp.uni -trier.de/db/journals/dcg/",
  "5 SPL  IEEE Signal Processing Letters  IEEE  http://dblp.uni -trier.de/db/journals/spl/",
  "6 IET -IPR  IET Image Processing  IET  http://dblp.uni -trier.de/db/journals/iet -ipr/",
  "7 JVCIR  Journal of Visual Communication and ImageRepresentation  Elsevier  http://dblp.uni -trier.de/db/journals/jvcir/",
  "8 MS  Multimedia Systems  Springer  http://dblp.uni -trier.de/db/journals/mms/",
  "9 MTA  Multimedia Tools and Applications  Springer  http://dblp.uni -trier.de/db/journals/mta/",
  "10   Signal Processing  Elsevier  http://dblp.uni -trier.de/db/journals/sigpro/",
  "11 SPIC  Signal Processing: Image Communication  Elsevier  http://dblp.uni -trier.de/db/journals/spic/",
  "12 TVC  The Visual Computer  Springer  http://dblp.uni -trier.de/db/journals/vc/",
  "1 TALLIP  ACM Transactions on Asian and Low -Resource  Language Information Processing  ACM  http://dblp.uni -trier.de/db/journals/talip/",
  "2   Applied Intelligence  Springer  http://dblp.uni -trier.de/db/journals/apin/",
  "3 AIM  Artificial Intelligence in Medicine  Elsevier  http://dblp.uni -trier.de/db/journals/artmed/",
  "4   Artificial Life  MIT Press  http://dblp.uni -trier.de/db/journals/alife/",
  "5   Computational Intelligence  Wiley  http://dblp.uni -trier.de/db/journals/ci/",
  "6   Computer Speech and Language  Elsevier  http://dblp.uni -trier.de/db/journals/csl/",
  "7   Connection Science  Taylor & Francis  http://dblp.uni -trier.de/db/journals/connection/",
  "8 DSS  Decision Support Systems  Elsevier  http://dblp.uni -trier.de/db/journals/dss/",
  "9 EAAI  Engineering Applications of ArtificialIntelligence  Elsevier  http://dblp.uni -trier.de/db/journals/eaai/",
  "10   Expert Systems  Blackwell/Wiley  http://dblp.uni -trier.de/db/journals/es/",
  "11 ESWA  Expert Systems with Applications  Elsevier  http://dblp.uni -trier.de/db/journals/eswa/",
  "12   Fuzzy Sets and Systems  Elsevier   http://dblp.uni -trier.de/db/journals/fss/",
  "13 TG  IEEE Transactions on Games  IEEE  http://dblp.uni -trier.de/db/journals/tciaig/",
  "14 IET -CVI  IET Computer Vision  IET  http://digital -library.theiet.org/content/journals/iet -cvi",
  "15   IET Signal Processing  IET  * http://digital -library.theiet.org/content/journals/iet -spr",
  "16 IVC  Image and Vision Computing  Elsevier  http://dblp.uni -trier.de/db/journals/ivc/  ",
  "17 IDA  Intelligent Data Analysis  IOS Press  http://dblp.uni -trier.de/db/journals/ida/",
  "18 IJCIA  International Journal of ComputationalIntelligence and Applications  World Scientific  http://dblp.uni -trier.de/db/journals/ijcia/",
  "19 IJIS  International Journal of Intelligent Systems  Wiley  http://dblp.uni -trier.de/db/journals/ijis/",
  "20 IJNS  International Journal of Neural Systems  World Scientific  http://dblp.uni -trier.de/db/journals/ijns/",
  "21 IJPRAI  International Journal of Pattern Recognitionand Artificial Intelligence  World Scientific  http://dblp.uni -trier.de/db/journals/ijprai/",
  "22 IJUFKS  International Journal of Uncertainty,Fuzziness and Knowledge -Based System  World Scientific  https://dblp.uni -trier.de/db/journals/ijufks/",
  "23 IJDAR  International Journal on Document Analysisand Recognition  Springer  http://dblp.uni -trier.de/db/journals/ijdar/",
  "24 JETAI  Journal of Experimental and TheoreticalArtificial Intelligence  Taylor & Francis  http://dblp.uni -trier.de/db/journals/jetai/",
  "25 KBS  Knowledge -Based Systems  Elsevier  http://dblp.uni -trier.de/db/journals/kbs/",
  "26   Machine Translation  Springer  http://dblp.uni -trier.de/db/journals/mt/",
  "27   Machine Vision and Applications  Springer  http://dblp.uni -trier.de/db/journals/mva/",
  "28   Natural Computing  Springer  http://dblp.uni -trier.de/db/journals/nc/",
  "29 NLE  Natural Language Engineering  CambridgeUniversity Press  http://dblp.uni -trier.de/db/journals/nle/",
  "30 NCA  Neural Computing & Applications  Springer  http://dblp.uni -trier.de/db/journals/nca/",
  "31 NPL  Neural Processing Letters  Springer  http://dblp.uni -trier.de/db/journals/npl/",
  "32   Neurocomputing  Elsevier  http://dblp.uni -trier.de/db/journals/ijon/  ",
  "33 PAA  Pattern Analysis and Applications  Springer  http://dblp.uni -trier.de/db/journals/paa/",
  "34 PRL  Pattern Recognition Letters  Elsevier  http://dblp.uni -trier.de/db/journals/prl/",
  "35   Soft Computing  Springer  http://dblp.uni -trier.de/db/journals/soco/",
  "36 WI  Web Intelligence  IOS Press  http://dblp.uni -trier.de/db/journals/wias/",
  "1 BIT  Behaviour & Information Technology  Taylor & Francis  http://dblp.uni -trier.de/db/journals/behaviourIT/",
  "2 PUC  Personal and Ubiquitous Computing  Springer  http://dblp.uni -trier.de/db/journals/puc/",
  "3 PMC  Pervasive and Mobile Computing  Elsevier  http://dblp.uni -trier.de/db/journals/percom/",
  "1  BMC Bioinformatics  BioMed Central  http://dblp.uni -trier.de/db/journals/bmcbi/",
  "2  Cybernetics and Systems  Taylor & Francis  http://dblp.uni -trier.de/db/journals/cas/",
  "3 FCS  Frontiers of Computer Science  Higher EducationPress  http://dblp.uni -trier.de/db/journals/fcsc/",
  "4  IEEE Geoscience and Remote SensingLetters  IEEE  http://dblp.uni -trier.de/db/journals/lgrs/",
  "5 JBHI  IEEE Journal of Biomedical and HealthInformatics  IEEE  http://dblp.uni -trier.de/db/journals/titb/",
  "6 TBD  IEEE Transactions on Big Data  IEEE  https://dblp.uni -trier.de/db/journals/tbd/",
  "7  IET Intelligent Transport Systems  IET  http://digital -library.theiet.org/content/journals/iet -its",
  "8 JBI  Journal of Biomedical Informatics  Elsevier  https://dblp.uni -trier.de/db/journals/jbi/",
  "9  Medical Image Analysis  Elsevier  http://dblp.uni -trier.de/db/journals/mia/  ",
  "1 CF ACM International Conference on Computing Frontiers  ACM  http://dblp.uni -trier.de/db/conf/cf",
  "2 SYSTOR  ACM International Systems and Storage Conference  ACM  http://dblp.uni -trier.de/db/conf/systor/index.html",
  "3 NOCS  ACM/IEEE International Symposium on Networks -on-Chip  ACM/IEEE  http://dblp.uni -trier.de/db/conf/nocs",
  "4 ASAP  Application -Specific Systems, Architectures, and Processors  IEEE  http://dblp.uni -trier.de/db/conf/asap",
  "5 ASP -DAC  Asia and South Pacific Design Automation Conference  ACM/IEEE  http://dblp.uni -trier.de/db/conf/aspdac",
  "6 Euro -Par  European Conference on Parallel and Distributed Computing  Springer  http://dblp.uni -trier.de/db/conf/europar/",
  "7 ETS  European Test Symposium  IEEE  http://dblp.uni -trier.de/db/conf/ets/",
  "8 FPL  Field Programmable Logic and Applications  IEEE  http://dblp.uni -trier.de/db/conf/fpl/",
  "9 FCCM  Field -Programmable Custom Computing Machines  IEEE  http://dblp.uni -trier.de/db/conf/fccm/",
  "10 GLSVLSI  Great Lakes Symposium on VLSI  ACM/IEEE  http://dblp.uni -trier.de/db/conf/glvlsi/",
  "11 ATS  IEEE Asian Test Symposium  IEEE  http://dblp.uni -trier.de/db/conf/ats/",
  "12 HPCC  IEEE International Conference on High PerformanceComputing and Communications  IEEE  http://dblp.uni -trier.de/db/conf/hpcc/",
  "13 HiPC IEEE International Conference on High PerformanceComputing, Data and Analytics  IEEE/ ACM  http://dblp.uni -trier.de/db/conf/hipc/index.html",
  "14 MASCOTS  IEEE International Symposium on Modeling, Analysis, andSimulation of Computer and Telecommunication Systems  IEEE  http://dblp.uni -trier.de/db/conf/mascots/  ",
  "15 ISPA  IEEE International Symposium on Parallel and DistributedProcessing with Applications  IEEE  http://dblp.uni -trier.de/db/conf/ispa/",
  "16 CCGRID  IEEE/ACM International Symposium on Cluster, Cloud andGrid Computing  ACM/IEEE  http://dblp.uni -trier.de/db/conf/ccgrid/",
  "17 NPC  IFIP International Conference on Network and ParallelComputing  Springer  http://dblp.uni -trier.de/db/conf/npc/",
  "18 ICA3PP  International Conference on Algorithms and Architectures forParallel Processing  IEEE  http://dblp.uni -trier.de/db/conf/ica3pp/",
  "19 CASES  International Conference on Compilers, Architectures, andSynthesis for Embedded Systems  ACM  http://dblp.uni -trier.de/db/conf/cases/index.html",
  "20 FPT  International Conference on Field -Programmable Technology  IEEE  http://dblp.uni -trier.de/db/conf/fpt/",
  "21 ICPADS  International Conference on Parallel and Distributed Systems  IEEE  http://dblp.uni -trier.de/db/conf/icpads/",
  "22 ISCAS  International Symposium on Circuits and Systems  IEEE  http://dblp.uni -trier.de/db/conf/iscas/",
  "23 ISLPED  International Symposium on Low Power Electronics andDesign  ACM/IEEE  http://dblp.uni -trier.de/db/conf/islped/",
  "24 ISPD  International Symposium on Physical Design  ACM  http://dblp.uni -trier.de/db/conf/ispd/",
  "25 Hot I Symposium on High -Performance Interconnects  IEEE  http://dblp.uni -trier.de/db/conf/hoti/",
  "26 VTS  VLSI Test Symposium  IEEE  http://dblp.uni -trier.de/db/conf/vts/  ",
  "1 ANCS  Architectures for Networking and Communications Systems  ACM/IEEE http://dblp.uni -trier.de/db/conf/ancs/",
  "2 APNOMS  Asia -Pacific Network Operations and Management Symposium  IFIP/IEEE  http://dblp.uni -trier.de/db/conf/apnoms/",
  "3 FORTE  Formal Techniques for Networked and Distributed Systems  Springer  http://dblp.uni -trier.de/db/conf/forte/",
  "4 LCN  IEEE Conference on Local Computer Networks  IEEE  http://dblp.uni -trier.de/db/conf/lcn/",
  "5 GLOBECOM IEEE Global Communications Conference  IEEE  http://dblp.uni -trier.de/db/conf/globecom/",
  "6 ICC  IEEE International Conference on Communications  IEEE  http://dblp.uni -trier.de/db/conf/icc/",
  "7 ICCCN  IEEE International Conference on Computer Communications andNetworks  IEEE  http://dblp.uni -trier.de/db/conf/icccn/",
  "8 MASS  IEEE International Conference on Mobile Ad -hoc and Sensor Systems  IEEE  http://dblp.uni -trier.de/db/conf/mass/index.html",
  "9 P2P  IEEE International Conference on Peer -to-Peer Computing  IEEE  http://dblp.uni -trier.de/db/conf/p2p/",
  "10 IPCCC  IEEE International Performance Computing and CommunicationsConference  IEEE  http://dblp.uni -trier.de/db/conf/ipccc/",
  "11 WoWMoM  IEEE International Symposium on a World of Wireless , Mobile andMultimedia Networks  IEEE  http://dblp.uni -trier.de/db/conf/wowmom/",
  "12 ISCC  IEEE Symposium on Computers and Communications  IEEE  http://dblp.uni -trier.de/db/conf/iscc/",
  "13 WCNC  IEEE Wireless Communications & Networking Conference  IEEE  http://dblp.uni -trier.de/db/conf/wcnc/  ",
  "14 Networking  IFIP International Conferences on Networking  IFIP  http://dblp.uni -trier.de/db/conf/networking/index.html",
  "15 IM IFIP/IEEE International Symposium on Integrated NetworkManagement  IFIP/IEEE  http://dblp.uni -trier.de/db/conf/im/index.html",
  "16 MSN  International Conference on Mobile Ad -hoc and Sensor Networks  IEEE  https://dblp.uni -trier.de/db/conf/msn/",
  "17 MSWiM  International Conference on Modeling, Analysis and Simulation ofWireless and Mobile Systems  ACM  http://dblp.uni -trier.de/db/conf/mswim/",
  "18 WASA  International Conference on Wireless Algorithms, Systems, andApplications  Springer  http://dblp.uni -trier.de/db/conf/wasa/",
  "19 HotNets  The Workshop on Hot Topics in Networks  ACM  http://dblp.uni -trier.de/db/conf/hotnets/",
  "1 WiSec  ACM Conference on Security and Privacy in Wireless andMobile Networks  ACM  http://dblp.uni -trier.de/db/conf/wisec/",
  "2 SACMAT  ACM Symposium on Access Control Models andTechnologies  ACM  http://dblp.uni -trier.de/db/conf/sacmat/",
  "3 DRM  ACM Workshop on Digital Rights Management  ACM  http://dblp.uni -trier.de/db/conf/drm/",
  "4 IH&MMSec  ACM Workshop on Information Hiding and MultimediaSecurity  ACM  http://dblp.uni -trier.de/db/conf/ih/",
  "5 ACNS  Applied Cryptography and Network Security  Springer  http://dblp.uni -trier.de/db/conf/acns/",
  "6 AsiaCCS  Asia Conference on Computer and Communications Security  ACM  http://dblp.uni -trier.de/db/conf/ccs/",
  "7 ACISP  Australasia Conference on Information Security and Privacy  Springer  http://dblp.uni -trier.de/db/conf/acisp/",
  "8 CT -RSA  Cryptographer's Track at RSA Conference  Springer  http://dblp.uni -trier.de/db/conf/ctrsa/",
  "9 DIMVA  Detection of Intrusions and Malware & VulnerabilityAssessment   http://dblp.uni -trier.de/db/conf/dimva/",
  "10 DFRWS  Digital Forensic Research Workshop  Elsevier  http://dblp.uni -trier.de/db/conf/dfrws/",
  "11 FC Financial Cryptography and Data Security  Springer  http://dblp.uni -trier.de/db/conf/fc/",
  "12 TrustCom  IEEE International Conference on Trust, Security and Privacyin Computing and Communications  IEEE  http://dblp.uni -trier.de/db/conf/trustcom/  ",
  "13 SEC  IFIP International Information Security Conference  Springer  http://dblp.uni -trier.de/db/conf/sec/",
  "14 IFIP WG 11.9  IFIP WG 11.9 International Conference on Digital Forensics  Springer  *http://www.ifip119.org/Conferences/",
  "15 ISC  Information Security Conference  Springer  http://dblp.uni -trier.de/db/conf/isw/",
  "16 ICDF2C  International Conference on Digital Forensics & Cyber Crime  Springer  http://dblp.uni -trier.de/db/conf/icdf2c/",
  "17 ICICS  International Conference on Information and CommunicationsSecurity  Springer  http://dblp.uni -trier.de/db/conf/icics/",
  "18 SecureComm  International Conference on Security and Privacy inCommunication Networks  ACM  http://dblp.uni -trier.de/db/conf/securecomm/",
  "19 NSPW  New Security Paradigms Workshop  ACM  http://dblp.uni -trier.de/db/conf/nspw/",
  "20 PAM  Passive and Active Measurement Conference  Springer  http://dblp.uni -trier.de/db/conf/pam/",
  "21 PETS  Privacy Enhancing Technologies Symposium  Springer  http://dblp.uni -trier.de/db/conf/pet/",
  "22 SAC  Selected Areas in Cryptography  Springer  http://dblp.uni -trier.de/db/conf/sacrypt/",
  "23 SOUPS  Symposium On Usable Privacy and Security  USENIX  http://dblp.uni -trier.de/db/conf/soups/",
  "24 HotSec  USENIX Workshop on Hot Topics in Security  USENIX  *http://www.usenix.org/events/",
  "1 PEPM  ACM SIGPLAN Workshop on Partial Evaluation and ProgramManipulation  ACM  http://dblp.uni -trier.de/db/conf/pepm/",
  "2 PASTE  ACMSIGPLAN -SIGSOFT Workshop on Program Analysisfor Software Tools and Engineering  ACM  http://dblp.uni -trier.de/db/conf/paste/",
  "3 APLAS  Asian Symposium on Programming Languages and Systems  Springer  http://dblp.uni -trier.de/db/conf/aplas/",
  "4 APSEC  Asia -Pacific Software Engineering Conference  IEEE  http://dblp.uni -trier.de/db/conf/apsec/",
  "5 EASE  Evaluation and Assessment in Software Engineering  ACM  http://dblp.uni -trier.de/db/conf/ease/",
  "6 ICECCS  IEEE International Conference on Engineering of ComplexComputer Systems  IEEE  http://dblp.uni -trier.de/db/conf/iceccs/",
  "7 ICST  IEEE International Conference on Software Testing,Verification and Validation  IEEE  http://dblp.uni -trier.de/db/conf/icst/",
  "8 ISPASS  IEEE International Symposium on Performance Analysis ofSystems and Software  IEEE  http://dblp.uni -trier.de/db/conf/ispass/",
  "9 SCAM  IEEE International Working Conference on Source CodeAnalysis and Manipulation  IEEE  http://dblp.uni -trier.de/db/conf/scam/",
  "10 COMPSAC  International Computer Software and Applications Conference  IEEE  http://dblp.uni -trier.de/db/conf/compsac/  ",
  "11 ICFEM  International Conference on Formal Engineering Methods  Springer  http://dblp.uni -trier.de/db/conf/icfem/",
  "12 TOOLS  International Conference on Objects, Models, Components,Patterns  Springer  http://dblp.uni -trier.de/db/conf/tools/index.html",
  "13 SCC  International Conference on Service Computing  IEEE  http://dblp.uni -trier.de/db/conf/IEEEscc/",
  "14 ICSSP  International Conference on Software and System Process  ACM  http://dblp.uni -trier.de/db/conf/ispw/",
  "15 SEKE  International Conference on Software Engineering andKnowledge Engineering  KSI  http://dblp.uni -trier.de/db/conf/seke/",
  "16 QRS  International Conference on Software Quality, Reliability andSecurity  IEEE  https://dblp.uni -trier.de/db/conf/qrs/",
  "17 ICSR  International Conference on Software Reuse  Springer  http://dblp.uni -trier.de/db/conf/icsr/",
  "18 ICWE  International Conference on Web Engineering  Springer  http://dblp.uni -trier.de/db/conf/icwe/",
  "19 SPIN  International SPIN Workshop on Model Checking Software  Springer  http://dblp.uni -trier.de/db/conf/spin/index.html",
  "20 ATVA  International Symposium on Automated Technology forVerification and Analysis  Springer  http://dblp.uni -trier.de/db/conf/atva/",
  "21 LOPSTR  International Symposium on Logic -based Program Synthesisand Transformation  Springer  http://dblp.uni -trier.de/db/conf/lopstr/",
  "22 TASE  International Symposium on Theoretical Aspects of SoftwareEngineering  IEEE  http://dblp.uni -trier.de/db/conf/tase/",
  "23 MSR  Mining Software Repositories  IEEE/ACM  http://dblp.uni -trier.de/db/conf/msr/",
  "24 REFSQ  Requirements Engineering: Foundation for Software Quality  Springer  http://dblp.uni -trier.de/db/conf/refsq/",
  "25 WICSA  Working IEEE/IFIP Conference on Software Architecture  IEEE  http://dblp.uni -trier.de/db/conf/wicsa/  ",
  "1 APWeb  Asia Pacific Web Conference  Springer  http://dblp.uni -trier.de/db/conf/apweb/",
  "2 DEXA  Database and Expert System Applications  Springer  http://dblp.uni -trier.de/db/conf/dexa/",
  "3 ECIR  European Conference on IR Research  Springer  http://dblp.uni -trier.de/db/conf/ecir/",
  "4 ESWC  Extended Semantic Web Conference  Springer  http://dblp.uni -trier.de/db/conf/esws/",
  "5 WebDB  International ACM Workshop on Web andDatabases  ACM  http://dblp.uni -trier.de/db/conf/webdb/",
  "6 ER  International Conference on ConceptualModeling  Springer  http://dblp.uni -trier.de/db/conf/er/",
  "7 MDM  International Conference on Mobile DataManagement  IEEE  http://dblp.uni -trier.de/db/conf/mdm/",
  "8 SSDBM  International Conference on Scientific andStatistical DB Management  IEEE  http://dblp.uni -trier.de/db/conf/ssdbm/",
  "9 WAIM  International Conference on Web AgeInformation Management  Springer  http://dblp.uni -trier.de/db/conf/waim/",
  "10 SSTD  International Symposium on Spatial andTemporal Databases  Springer  http://dblp.uni -trier.de/db/conf/ssd/",
  "11 PAKDD  Pacific -Asia Conference on KnowledgeDiscovery and Data Mining  Springer  http://dblp.uni -trier.de/db/conf/pakdd/",
  "12 WISE  Web Information Systems Engineering  Springer  http://dblp.uni -trier.de/db/conf/wise/",
  "1 CSL  Computer Science Logic  Springer  http://dblp.uni -trier.de/db/conf/csl/",
  "2 FMCAD  Formal Methods in Computer -Aided Design  ACM  http://dblp.uni -trier.de/db/conf/fmcad/",
  "3 FSTTCS  Foundations of Software Technology andTheoretical Computer Science  Indian Association for Researchin Computing Science  http://dblp.uni -trier.de/db/conf/fsttcs/",
  "4 DSAA  IEEE International Conference on Data Scienceand Advanced Analytics  IEEE  https://dblp.uni -trier.de/db/conf/dsaa/",
  "5 ICTAC  International Colloquium on Theoretical Aspectsof Computing  Springer  http://dblp.uni -trier.de/db/conf/ictac/",
  "6 IPCO  International Conference on Integer Programmingand Combinatorial Optimization  Springer  http://dblp.uni -trier.de/db/conf/ipco/",
  "7 RTA  International Conference on RewritingTechniques and Applications  Springer  http://dblp.uni -trier.de/db/conf/rta/",
  "8 ISAAC  International Symposium on Algorithms andComputation  Springer  http://dblp.uni -trier.de/db/conf/isaac/",
  "9 MFCS  Mathematical Foundations of Computer Science  Springer  http://dblp.uni -trier.de/db/conf/mfcs/",
  "10 STACS  Symposium on Theoretical Aspects of ComputerScience  Springer  http://dblp.uni -trier.de/db/conf/stacs/",
  "1   ACM Symposium on Virtual RealitySoftware and Technology  ACM  http://dblp2.uni -trier.de/db/conf/vrst/",
  "2 CASA  Computer Animation and Social Agents  Wiley  http://dblp.uni -trier.de/db/conf/ca/",
  "3 CGI  Computer Graphics International  Springer  http://dblp.uni -trier.de/db/conf/cgi/",
  "4 INTERSPEECH  Conference of the International SpeechCommunication Association    http://dblp.uni -trier.de/db/conf/interspeech/index.html",
  "5 GMP  Geometric Modeling and Processing  Elsevier  http://dblp.uni -trier.de/db/conf/gmp/",
  "6 PacificVis  IEEE Pacific Visualization Symposium  IEEE  http://dblp.uni -trier.de/db/conf/apvis/",
  "7 3DV  International Conference on 3D Vision  IEEE  https://dblp.uni -trier.de/db/conf/3dim/",
  "8 CAD/Graphics  International Conference on Computer -AidedDesign and Computer Graphics  IEEE  https://dblp.uni -trier.de/db/conf/cadgraphics/",
  "9 ICIP  International Conference on Image Processing  IEEE  http://dblp.uni -trier.de/db/conf/icip/",
  "10 MMM  International Conference on MultimediaModeling  Springer  http://dblp.uni -trier.de/db/conf/mmm/index.html",
  "11 PCM  Pacific -Rim Conference on Multimedia  Springer  http://dblp.uni -trier.de/db/conf/pcm/",
  "12 SMI  Shape Modeling International  IEEE  http://dblp.uni -trier.de/db/conf/smi/  ",
  "1 AISTATS  Artificial Intelligence and Statistics  JMLR  http://dblp.uni -trier.de/db/conf/aistats/",
  "2 ACCV  Asian Conference on Computer Vision  Springer  http://dblp.uni -trier.de/db/conf/accv/",
  "3 ACML  Asian Conference on MachineLearning  JMLR  http://dblp.uni -trier.de/db/conf/acml/",
  "4 BMVC  British Machine Vision Conference   British Machine VisionAssociation  http://dblp.uni -trier.de/db/conf/bmvc/",
  "5 NLPCC  CCF International Conference onNatural Language Pro cessing andChinese Computing  Springer  https://dblp.uni -trier.de/db/conf/nlpcc/",
  "6 CoNLL  Conference on Computational NaturalLanguage Learning  Association forComputational Linguistics  http://dblp.uni -trier.de/db/conf/conll",
  "7 GECCO  Genetic and Evolutionary ComputationConference  ACM  http://dblp.uni -trier.de/db/conf/gecco/",
  "8 ICTAI  IEEE International Conference onTools with Artificial Intelligence  IEEE  http://dblp.uni -trier.de/db/conf/ictai/",
  "9 IROS  IEEE \\RSJ International Conference onIntelligent Robots and Systems  IEEE  http://dblp.uni -trier.de/db/conf/iros/",
  "10 ALT  International Conference onAlgorithmic Learning Theory  Springer  http://dblp.uni -trier.de/db/conf/alt/",
  "11 ICANN  International Conference on ArtificialNeural Networks  Springer  http://dblp.uni -trier.de/db/conf/icann/",
  "12 FG  International Conference on AutomaticFace and Gesture Recognition  IEEE  http://dblp.uni -trier.de/db/conf/fgr/  ",
  "13 ICDAR  International Conference on DocumentAnalysis and Recognition  IEEE  http://dblp.uni -trier.de/db/conf/icdar/",
  "14 ILP  International Conference on InductiveLogic Programming  Springer  http://dblp.uni -trier.de/db/conf/ilp/",
  "15 KSEM  International conference on KnowledgeScience,  Engineering and Management  Springer  http://dblp.uni -trier.de/db/conf/ksem/",
  "16 ICONIP  International Conference on NeuralInformation Processing  Springer  http://dblp.uni -trier.de/db/conf/iconip/",
  "17 ICPR  International Conference on PatternRecognition  IEEE  http://dblp.uni -trier.de/db/conf/icpr/",
  "18 ICB  International Joint Conference onBiometrics  IEEE  http://dblp.uni -trier.de/db/conf/icb/",
  "19 IJCNN  International Joint Conference onNeural Networks  IEEE  http://dblp.uni -trier.de/db/conf/ijcnn/",
  "20 PRICAI  Pacific Rim International Conferenceon Artificial Intelligence  Springer  http://dblp.uni -trier.de/db/conf/pricai/",
  "21 NAACL  The Annual Conference of the NorthAmerican Chapter of the Association for Computational Linguistics  NAACL  http://dblp.uni -trier.de/db/conf/naacl/  ",
  "1 DIS  ACM Conference on Designing Interactive Systems  ACM  http://dblp.uni -trier.de/db/conf/ACMdis",
  "2 ICMI   ACM International Conference on Multimodal Interaction  ACM  http://dblp.uni -trier.de/db/conf/icmi/",
  "3 ASSETS  ACM SIGACCESS Conference on Computers and Accessibility  ACM  http://dblp.uni -trier.de/db/conf/assets",
  "4 GI Graphics Interface conference  ACM  http://dblp.uni -trier.de/db/conf/graphicsinterface/",
  "5 UIC  IEEE International Conference on Ubiquitous Intelligence andComputing  IEEE  http://dblp.uni -trier.de/db/conf/uic/",
  "6  IEEE World Haptics Conference  IEEE  http://dblp.uni -trier.de/db/conf/haptics/",
  "7 INTERACT  IFIP TC13 Conference on Human -Computer Interaction  IFIP  http://dblp.uni -trier.de/db/conf/interact/",
  "8 IDC  Interaction Design and Children  ACM  http://dblp.uni -trier.de/db/conf/acmidc/",
  "9 CollaborateCom  International Conference on Collaborative Computing:Networking, Applications and Worksharing  Springer  http://collaboratecom.org",
  "10 CSCWD  International Conference on Computer Supported CooperativeWork in Design  Springer  http://dblp.uni -trier.de/db/conf/cscwd/",
  "11 CoopIS  International Conference on Cooperative Information Systems  Springer  http://dblp.uni -trier.de/db/conf/coopis/",
  "12 MobiQuitous  International Conference on Mobile and Ubiquitous Systems:Computing, Networking and Services  Springer  http://dblp.uni -trier.de/db/conf/mobiquitous/",
  "13 AVI  International Working Conference on Advanced Visual Interfaces  ACM  http://dblp.uni -trier.de/db/conf/avi/  ",
  "1 AMIA  American Medical Informatics AssociationAnnual Symposium  AMIA  http://dblp.uni -trier.de/db/conf/amia/",
  "2 APBC  Asia Pacific Bioinformatics Conference  BioMed Central  http://dblp.uni -trier.de/db/conf/apbc/",
  "3  IEEE International Conference on Big Data  IEEE  https://dblp.uni -trier.de/db/conf/bigdataconf/",
  "4  IEEE International Conference on CloudComputing  IEEE  http://dblp.uni -trier.de/db/conf/IEEEcloud/",
  "5 SMC  IEEE International Conference on Systems,Man, and Cybernetics  IEEE  https://dblp.uni -trier.de/db/conf/smc/",
  "6 COSIT  International Conference on Spatial InformationTheory  ACM  http://dblp.uni -trier.de/db/conf/cosit/",
  "7 ISBRA  International Symposium on BioinformaticsResearch and Applications  Springer  https://dblp.uni -trier.de/db/conf/isbra/"
]